@@ -75,7 +75,7 @@ test_that("Create very basic model on the fly", {
 
 test_that("Equations can be removed", {
   
-  model <- model_library$advan1_trans1
+  model <- model_suite$nonmem$advan1_trans1
   expect_equal(model %>% find(MainRecord()) %>% length(), 3) # 3 equations: K, V, S1
   
   model <- model %>% delete(Equation("S1"))
@@ -84,7 +84,7 @@ test_that("Equations can be removed", {
 
 test_that("Equations can be replaced", {
   
-  model <- model_library$advan1_trans1
+  model <- model_suite$nonmem$advan1_trans1
   expect_equal(model %>% find(MainRecord()) %>% length(), 3) # 3 equations: K, V, S1
   
   model <- model %>% replace(Equation("S1", "V/1000"))
@@ -94,7 +94,7 @@ test_that("Equations can be replaced", {
 
 test_that("Equations can be added at a specific position", {
   
-  model <- model_library$advan1_trans1
+  model <- model_suite$nonmem$advan1_trans1
   
   model1 <- model %>% add(Equation("V2", "THETA_V2*exp(ETA_V2)"), Position(Equation("V")))
   model2 <- model %>% add(Equation("V2", "THETA_V2*exp(ETA_V2)"), Position(Equation("S1"), after=FALSE))
@@ -111,11 +111,16 @@ test_that("Equations can be added at a specific position", {
   model6 <- model %>% add(Equation("V2", "THETA_V2*exp(ETA_V2)"), Position(3, after=FALSE))
   
   expect_equal(model5, model6)
+  
+  # Delete the added equation (by index vs by equation, works only at the level of the code record)
+  main1 <- model1 %>% find(MainRecord())
+  main2 <- model2 %>% find(MainRecord())
+  expect_equal(main1 %>% delete(3L), main2 %>% delete(Equation("V2")))
 })
 
 test_that("Find method works well to search for a specific equation", {
   
-  model <- model_library$advan1_trans1
+  model <- model_suite$nonmem$advan1_trans1
   equation <- model %>% find(Equation("V"))
   expect_equal(equation@rhs, "THETA_V*exp(ETA_V)")
   
@@ -125,14 +130,14 @@ test_that("Find method works well to search for a specific equation", {
 
 test_that("Contains method can be used to check the existence of an equation", {
   
-  model <- model_library$advan1_trans1
+  model <- model_suite$nonmem$advan1_trans1
   expect_true(model %>% contains(Equation("V")))
   expect_false(model %>% contains(Equation("V2")))
 })
 
 test_that("Add IF-statements at specific locations in the model", {
   
-  model <- model_library$advan1_trans1
+  model <- model_suite$nonmem$advan1_trans1
   
   if1 <- IfStatement("COV==1", Equation("V", "V*1.0"))
   if2 <- IfStatement("COV==2", Equation("V", "V*1.1"))
@@ -154,7 +159,7 @@ test_that("Add IF-statements at specific locations in the model", {
 
 test_that("Add model statements into the given code record", {
   
-  model <- model_library$advan1_trans1
+  model <- model_suite$nonmem$advan1_trans1
   
   cp <- Equation("CP", "A_CENTRAL/S1")
   
@@ -174,4 +179,7 @@ test_that("Add model statements into the given code record", {
   
   ode2 <- model2 %>% find(OdeRecord())
   expect_equal(ode2@statements %>% getByIndex(3), cp)
+  
+  # x in Position() must be either a PMX element or an integer
+  expect_error(Position(data.frame(), after=FALSE), regexp="x can only be a PMX element or an integer position")
 })
